package com.ycwl.basic.service.impl.pc;

import cn.hutool.core.bean.BeanUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.ycwl.basic.mapper.pc.OrderMapper;
import com.ycwl.basic.model.pc.order.entity.OrderItemEntity;
import com.ycwl.basic.model.pc.order.req.OrderAddOrUpdateReq;
import com.ycwl.basic.model.pc.order.req.OrderItemDTO;
import com.ycwl.basic.model.pc.order.req.OrderReqQuery;
import com.ycwl.basic.model.pc.order.resp.OrderRespVO;
import com.ycwl.basic.service.pc.OrderService;
import com.ycwl.basic.utils.ApiResponse;
import com.ycwl.basic.utils.SnowFlakeUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * @Author：longbinbin
 * @Date：2024/12/3 13:54
 */
@Slf4j
@Service
public class OrderServiceImpl implements OrderService {

    @Autowired
    private OrderMapper orderMapper;

    @Override
    public ApiResponse<PageInfo<OrderRespVO>> pageQuery(OrderReqQuery query) {
        PageHelper.startPage(query.getPageNum(), query.getPageSize());
        List<OrderRespVO> list = orderMapper.list(query);
        PageInfo<OrderRespVO> pageInfo = new PageInfo<>(list);
        return ApiResponse.success(pageInfo);
    }

    @Override
    public ApiResponse<List<OrderRespVO>> list(OrderReqQuery query) {
        return ApiResponse.success(orderMapper.list(query));
    }

    @Override
    public ApiResponse<OrderRespVO> detail(Long orderId) {
        return ApiResponse.success(orderMapper.getById(orderId));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ApiResponse<Integer> add(OrderAddOrUpdateReq order) {
        Long orderId = SnowFlakeUtil.getLongId();
        order.setId(orderId);
        int add = orderMapper.add(order);
        if (add == 0) {
            return ApiResponse.fail("订单添加失败");
        }else {
            List<OrderItemDTO> orderItemList = order.getOrderItemList();
            List<OrderItemEntity> orderItems = new ArrayList<>();
            orderItemList.forEach(orderItemDTO -> {
                OrderItemEntity orderItemEntity = new OrderItemEntity();
                BeanUtil.copyProperties(orderItemDTO, orderItemEntity);
                orderItemEntity.setOrderId(orderId);
            });
            int addOrderItems = orderMapper.addOrderItems(orderItems);
            if (addOrderItems == 0) {
                log.error("订单明细添加失败");
                return ApiResponse.fail("订单添加失败");
            }
            return ApiResponse.success(add);
        }
    }

    @Override
    public ApiResponse<Integer> update(OrderAddOrUpdateReq query) {
        int update = orderMapper.update(query);
        if (update == 0) {
            return ApiResponse.fail("订单更新失败");
        }
        return ApiResponse.success(update);
    }
}
